# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_worker/protos/PPEDetectionService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_worker/protos/PPEDetectionService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3nedo_vision_worker/protos/PPEDetectionService.proto\x12\x1eSindika.AspNet.App005.Services\">\n\x1aUpsertPPEDetectionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"C\n\x1fUpsertPPEDetectionBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xff\x01\n\x19UpsertPPEDetectionRequest\x12\x11\n\tperson_id\x18\x01 \x01(\t\x12\x11\n\tworker_id\x18\x02 \x01(\t\x12\x18\n\x10worker_source_id\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\x0c\x12\x18\n\x10worker_timestamp\x18\x05 \x01(\t\x12V\n\x14ppe_detection_labels\x18\x06 \x03(\x0b\x32\x38.Sindika.AspNet.App005.Services.PPEDetectionLabelRequest\x12\x12\n\nimage_tile\x18\x07 \x01(\x0c\x12\r\n\x05token\x18\x08 \x01(\t\"\x99\x01\n\x18PPEDetectionLabelRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x18\n\x10\x63onfidence_score\x18\x02 \x01(\x01\x12\x10\n\x08\x62_box_x1\x18\x03 \x01(\x01\x12\x10\n\x08\x62_box_y1\x18\x04 \x01(\x01\x12\x10\n\x08\x62_box_x2\x18\x05 \x01(\x01\x12\x10\n\x08\x62_box_y2\x18\x06 \x01(\x01\x12\r\n\x05token\x18\x07 \x01(\t\"\x8a\x01\n\x1eUpsertPPEDetectionBatchRequest\x12Y\n\x16ppe_detection_requests\x18\x01 \x03(\x0b\x32\x39.Sindika.AspNet.App005.Services.UpsertPPEDetectionRequest\x12\r\n\x05token\x18\x02 \x01(\t2\xab\x02\n\x17PPEDetectionGRPCService\x12\x7f\n\x06Upsert\x12\x39.Sindika.AspNet.App005.Services.UpsertPPEDetectionRequest\x1a:.Sindika.AspNet.App005.Services.UpsertPPEDetectionResponse\x12\x8e\x01\n\x0bUpsertBatch\x12>.Sindika.AspNet.App005.Services.UpsertPPEDetectionBatchRequest\x1a?.Sindika.AspNet.App005.Services.UpsertPPEDetectionBatchResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_worker.protos.PPEDetectionService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UPSERTPPEDETECTIONRESPONSE']._serialized_start=87
  _globals['_UPSERTPPEDETECTIONRESPONSE']._serialized_end=149
  _globals['_UPSERTPPEDETECTIONBATCHRESPONSE']._serialized_start=151
  _globals['_UPSERTPPEDETECTIONBATCHRESPONSE']._serialized_end=218
  _globals['_UPSERTPPEDETECTIONREQUEST']._serialized_start=221
  _globals['_UPSERTPPEDETECTIONREQUEST']._serialized_end=476
  _globals['_PPEDETECTIONLABELREQUEST']._serialized_start=479
  _globals['_PPEDETECTIONLABELREQUEST']._serialized_end=632
  _globals['_UPSERTPPEDETECTIONBATCHREQUEST']._serialized_start=635
  _globals['_UPSERTPPEDETECTIONBATCHREQUEST']._serialized_end=773
  _globals['_PPEDETECTIONGRPCSERVICE']._serialized_start=776
  _globals['_PPEDETECTIONGRPCSERVICE']._serialized_end=1075
# @@protoc_insertion_point(module_scope)
