# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_worker/protos/WorkerSourcePipelineService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_worker/protos/WorkerSourcePipelineService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;nedo_vision_worker/protos/WorkerSourcePipelineService.proto\x12\x1eSindika.AspNet.App005.Services\"\x90\x01\n WorkerSourcePipelineListResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12J\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32<.Sindika.AspNet.App005.Services.WorkerSourcePipelineResponse\"<\n\x18GetListByWorkerIdRequest\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"I\n\x1eGetListByWorkerSourceIdRequest\x12\x18\n\x10worker_source_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"\x9b\x02\n\x1cWorkerSourcePipelineResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10worker_source_id\x18\x03 \x01(\t\x12\x11\n\tworker_id\x18\x04 \x01(\t\x12\x13\n\x0b\x61i_model_id\x18\x05 \x01(\t\x12\x1c\n\x14pipeline_status_code\x18\x06 \x01(\t\x12j\n\x1eworker_source_pipeline_configs\x18\x07 \x03(\x0b\x32\x42.Sindika.AspNet.App005.Services.WorkerSourcePipelineConfigResponse\x12\x15\n\rlocation_name\x18\x08 \x01(\t\"\xe3\x01\n\"WorkerSourcePipelineConfigResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12!\n\x19worker_source_pipeline_id\x18\x02 \x01(\t\x12\x1a\n\x12pipeline_config_id\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\r\n\x05value\x18\x05 \x01(\t\x12O\n\x0fpipeline_config\x18\x06 \x01(\x0b\x32\x36.Sindika.AspNet.App005.Services.PipelineConfigResponse\"@\n\x16PipelineConfigResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\"i\n\x18SendPipelineImageRequest\x12!\n\x19worker_source_pipeline_id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\x0c\x12\r\n\x05token\x18\x04 \x01(\t\"=\n\x19SendPipelineImageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"i\n\x1bUpdatePipelineStatusRequest\x12\x13\n\x0bpipeline_id\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\r\n\x05token\x18\x04 \x01(\t\"@\n\x1cUpdatePipelineStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"w\n\x18SendPipelineDebugRequest\x12!\n\x19worker_source_pipeline_id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\x0c\x12\r\n\x05token\x18\x05 \x01(\t\"=\n\x19SendPipelineDebugResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x92\x01\n SendPipelineDetectionDataRequest\x12!\n\x19worker_source_pipeline_id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\x0c\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\r\n\x05token\x18\x06 \x01(\t\"E\n!SendPipelineDetectionDataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t2\x92\x07\n\x1bWorkerSourcePipelineService\x12\x8f\x01\n\x11GetListByWorkerId\x12\x38.Sindika.AspNet.App005.Services.GetListByWorkerIdRequest\x1a@.Sindika.AspNet.App005.Services.WorkerSourcePipelineListResponse\x12\x9b\x01\n\x17GetListByWorkerSourceId\x12>.Sindika.AspNet.App005.Services.GetListByWorkerSourceIdRequest\x1a@.Sindika.AspNet.App005.Services.WorkerSourcePipelineListResponse\x12\x88\x01\n\x11SendPipelineImage\x12\x38.Sindika.AspNet.App005.Services.SendPipelineImageRequest\x1a\x39.Sindika.AspNet.App005.Services.SendPipelineImageResponse\x12\x89\x01\n\x0cUpdateStatus\x12;.Sindika.AspNet.App005.Services.UpdatePipelineStatusRequest\x1a<.Sindika.AspNet.App005.Services.UpdatePipelineStatusResponse\x12\x88\x01\n\x11SendPipelineDebug\x12\x38.Sindika.AspNet.App005.Services.SendPipelineDebugRequest\x1a\x39.Sindika.AspNet.App005.Services.SendPipelineDebugResponse\x12\xa0\x01\n\x19SendPipelineDetectionData\x12@.Sindika.AspNet.App005.Services.SendPipelineDetectionDataRequest\x1a\x41.Sindika.AspNet.App005.Services.SendPipelineDetectionDataResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_worker.protos.WorkerSourcePipelineService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_WORKERSOURCEPIPELINELISTRESPONSE']._serialized_start=96
  _globals['_WORKERSOURCEPIPELINELISTRESPONSE']._serialized_end=240
  _globals['_GETLISTBYWORKERIDREQUEST']._serialized_start=242
  _globals['_GETLISTBYWORKERIDREQUEST']._serialized_end=302
  _globals['_GETLISTBYWORKERSOURCEIDREQUEST']._serialized_start=304
  _globals['_GETLISTBYWORKERSOURCEIDREQUEST']._serialized_end=377
  _globals['_WORKERSOURCEPIPELINERESPONSE']._serialized_start=380
  _globals['_WORKERSOURCEPIPELINERESPONSE']._serialized_end=663
  _globals['_WORKERSOURCEPIPELINECONFIGRESPONSE']._serialized_start=666
  _globals['_WORKERSOURCEPIPELINECONFIGRESPONSE']._serialized_end=893
  _globals['_PIPELINECONFIGRESPONSE']._serialized_start=895
  _globals['_PIPELINECONFIGRESPONSE']._serialized_end=959
  _globals['_SENDPIPELINEIMAGEREQUEST']._serialized_start=961
  _globals['_SENDPIPELINEIMAGEREQUEST']._serialized_end=1066
  _globals['_SENDPIPELINEIMAGERESPONSE']._serialized_start=1068
  _globals['_SENDPIPELINEIMAGERESPONSE']._serialized_end=1129
  _globals['_UPDATEPIPELINESTATUSREQUEST']._serialized_start=1131
  _globals['_UPDATEPIPELINESTATUSREQUEST']._serialized_end=1236
  _globals['_UPDATEPIPELINESTATUSRESPONSE']._serialized_start=1238
  _globals['_UPDATEPIPELINESTATUSRESPONSE']._serialized_end=1302
  _globals['_SENDPIPELINEDEBUGREQUEST']._serialized_start=1304
  _globals['_SENDPIPELINEDEBUGREQUEST']._serialized_end=1423
  _globals['_SENDPIPELINEDEBUGRESPONSE']._serialized_start=1425
  _globals['_SENDPIPELINEDEBUGRESPONSE']._serialized_end=1486
  _globals['_SENDPIPELINEDETECTIONDATAREQUEST']._serialized_start=1489
  _globals['_SENDPIPELINEDETECTIONDATAREQUEST']._serialized_end=1635
  _globals['_SENDPIPELINEDETECTIONDATARESPONSE']._serialized_start=1637
  _globals['_SENDPIPELINEDETECTIONDATARESPONSE']._serialized_end=1706
  _globals['_WORKERSOURCEPIPELINESERVICE']._serialized_start=1709
  _globals['_WORKERSOURCEPIPELINESERVICE']._serialized_end=2623
# @@protoc_insertion_point(module_scope)
