# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_worker/protos/DatasetSourceService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_worker/protos/DatasetSourceService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4nedo_vision_worker/protos/DatasetSourceService.proto\x12\x1eSindika.AspNet.App005.Services\",\n\x1bGetDatasetSourceListRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x82\x01\n\x19\x44\x61tasetSourceListResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x43\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x35.Sindika.AspNet.App005.Services.DatasetSourceResponse\"\xb9\x01\n\x15\x44\x61tasetSourceResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x18\n\x10worker_source_id\x18\x03 \x01(\t\x12\x19\n\x11sampling_interval\x18\x04 \x01(\x05\x12\x14\n\x0c\x64\x61taset_name\x18\x05 \x01(\t\x12\x1a\n\x12worker_source_name\x18\x06 \x01(\t\x12\x19\n\x11worker_source_url\x18\x07 \x01(\t\"s\n\x17SendDatasetFrameRequest\x12\x19\n\x11\x64\x61taset_source_id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\r\n\x05token\x18\x05 \x01(\t\"<\n\x18SendDatasetFrameResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t2\xaf\x02\n\x14\x44\x61tasetSourceService\x12\x8e\x01\n\x14GetDatasetSourceList\x12;.Sindika.AspNet.App005.Services.GetDatasetSourceListRequest\x1a\x39.Sindika.AspNet.App005.Services.DatasetSourceListResponse\x12\x85\x01\n\x10SendDatasetFrame\x12\x37.Sindika.AspNet.App005.Services.SendDatasetFrameRequest\x1a\x38.Sindika.AspNet.App005.Services.SendDatasetFrameResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_worker.protos.DatasetSourceService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETDATASETSOURCELISTREQUEST']._serialized_start=88
  _globals['_GETDATASETSOURCELISTREQUEST']._serialized_end=132
  _globals['_DATASETSOURCELISTRESPONSE']._serialized_start=135
  _globals['_DATASETSOURCELISTRESPONSE']._serialized_end=265
  _globals['_DATASETSOURCERESPONSE']._serialized_start=268
  _globals['_DATASETSOURCERESPONSE']._serialized_end=453
  _globals['_SENDDATASETFRAMEREQUEST']._serialized_start=455
  _globals['_SENDDATASETFRAMEREQUEST']._serialized_end=570
  _globals['_SENDDATASETFRAMERESPONSE']._serialized_start=572
  _globals['_SENDDATASETFRAMERESPONSE']._serialized_end=632
  _globals['_DATASETSOURCESERVICE']._serialized_start=635
  _globals['_DATASETSOURCESERVICE']._serialized_end=938
# @@protoc_insertion_point(module_scope)
