# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from nedo_vision_worker.protos import WorkerSourcePipelineService_pb2 as nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in nedo_vision_worker/protos/WorkerSourcePipelineService_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class WorkerSourcePipelineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetListByWorkerId = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/GetListByWorkerId',
                request_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.GetListByWorkerIdRequest.SerializeToString,
                response_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.WorkerSourcePipelineListResponse.FromString,
                _registered_method=True)
        self.GetListByWorkerSourceId = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/GetListByWorkerSourceId',
                request_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.GetListByWorkerSourceIdRequest.SerializeToString,
                response_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.WorkerSourcePipelineListResponse.FromString,
                _registered_method=True)
        self.SendPipelineImage = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/SendPipelineImage',
                request_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineImageRequest.SerializeToString,
                response_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineImageResponse.FromString,
                _registered_method=True)
        self.UpdateStatus = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/UpdateStatus',
                request_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.UpdatePipelineStatusRequest.SerializeToString,
                response_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.UpdatePipelineStatusResponse.FromString,
                _registered_method=True)
        self.SendPipelineDebug = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/SendPipelineDebug',
                request_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDebugRequest.SerializeToString,
                response_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDebugResponse.FromString,
                _registered_method=True)
        self.SendPipelineDetectionData = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/SendPipelineDetectionData',
                request_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDetectionDataRequest.SerializeToString,
                response_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDetectionDataResponse.FromString,
                _registered_method=True)


class WorkerSourcePipelineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetListByWorkerId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetListByWorkerSourceId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPipelineImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPipelineDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPipelineDetectionData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkerSourcePipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetListByWorkerId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetListByWorkerId,
                    request_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.GetListByWorkerIdRequest.FromString,
                    response_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.WorkerSourcePipelineListResponse.SerializeToString,
            ),
            'GetListByWorkerSourceId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetListByWorkerSourceId,
                    request_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.GetListByWorkerSourceIdRequest.FromString,
                    response_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.WorkerSourcePipelineListResponse.SerializeToString,
            ),
            'SendPipelineImage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPipelineImage,
                    request_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineImageRequest.FromString,
                    response_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineImageResponse.SerializeToString,
            ),
            'UpdateStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateStatus,
                    request_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.UpdatePipelineStatusRequest.FromString,
                    response_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.UpdatePipelineStatusResponse.SerializeToString,
            ),
            'SendPipelineDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPipelineDebug,
                    request_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDebugRequest.FromString,
                    response_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDebugResponse.SerializeToString,
            ),
            'SendPipelineDetectionData': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPipelineDetectionData,
                    request_deserializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDetectionDataRequest.FromString,
                    response_serializer=nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDetectionDataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Sindika.AspNet.App005.Services.WorkerSourcePipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('Sindika.AspNet.App005.Services.WorkerSourcePipelineService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WorkerSourcePipelineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetListByWorkerId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/GetListByWorkerId',
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.GetListByWorkerIdRequest.SerializeToString,
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.WorkerSourcePipelineListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetListByWorkerSourceId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/GetListByWorkerSourceId',
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.GetListByWorkerSourceIdRequest.SerializeToString,
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.WorkerSourcePipelineListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendPipelineImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/SendPipelineImage',
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineImageRequest.SerializeToString,
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineImageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/UpdateStatus',
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.UpdatePipelineStatusRequest.SerializeToString,
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.UpdatePipelineStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendPipelineDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/SendPipelineDebug',
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDebugRequest.SerializeToString,
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDebugResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendPipelineDetectionData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.WorkerSourcePipelineService/SendPipelineDetectionData',
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDetectionDataRequest.SerializeToString,
            nedo__vision__worker_dot_protos_dot_WorkerSourcePipelineService__pb2.SendPipelineDetectionDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
