# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_worker/protos/VisionWorkerService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_worker/protos/VisionWorkerService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3nedo_vision_worker/protos/VisionWorkerService.proto\x12\x1eSindika.AspNet.App005.Services\"/\n\x1eGetWorkerConnectionInfoRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\xbf\x01\n\x1fGetWorkerConnectionInfoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrabbitmq_host\x18\x03 \x01(\t\x12\x15\n\rrabbitmq_port\x18\x04 \x01(\x05\x12\x19\n\x11rabbitmq_username\x18\x05 \x01(\t\x12\x19\n\x11rabbitmq_password\x18\x06 \x01(\t\x12\x0f\n\x02id\x18\x07 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_id\"\xff\x01\n\x12SystemUsageRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x11\n\tcpu_usage\x18\x02 \x01(\x02\x12\x17\n\x0f\x63pu_temperature\x18\x03 \x01(\x02\x12\x19\n\x11ram_usage_percent\x18\x04 \x01(\x02\x12\x11\n\tram_total\x18\x05 \x01(\x04\x12\x10\n\x08ram_used\x18\x06 \x01(\x04\x12\x10\n\x08ram_free\x18\x07 \x01(\x04\x12\x35\n\x03gpu\x18\x08 \x03(\x0b\x32(.Sindika.AspNet.App005.Services.GPUUsage\x12\x12\n\nlatency_ms\x18\t \x01(\x02\x12\r\n\x05token\x18\n \x01(\t\"\xb3\x01\n\x08GPUUsage\x12\x11\n\tgpu_index\x18\x01 \x01(\x05\x12\x19\n\x11gpu_usage_percent\x18\x02 \x01(\x02\x12\x1c\n\x14memory_usage_percent\x18\x03 \x01(\x02\x12\x1b\n\x13temperature_celsius\x18\x04 \x01(\x02\x12\x14\n\x0ctotal_memory\x18\x05 \x01(\x04\x12\x13\n\x0bused_memory\x18\x06 \x01(\x04\x12\x13\n\x0b\x66ree_memory\x18\x07 \x01(\x04\"7\n\x13SystemUsageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"8\n\x14LastImageDateRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"U\n\x15LastImageDateResponse\x12\x1a\n\x12last_uploaded_date\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\"\\\n\x12UploadImageRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x12\n\nimage_data\x18\x03 \x01(\x0c\x12\r\n\x05token\x18\x04 \x01(\t\"7\n\x13UploadImageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x14\n\x12HealthCheckRequest\"%\n\x13HealthCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"T\n\nVideoFrame\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x12\n\nframe_data\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\"1\n\rVideoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"e\n\x19UpdateWorkerStatusRequest\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\r\n\x05token\x18\x04 \x01(\t\">\n\x1aUpdateWorkerStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t2\xb0\x03\n\x13VisionWorkerService\x12\x94\x01\n\x11GetConnectionInfo\x12>.Sindika.AspNet.App005.Services.GetWorkerConnectionInfoRequest\x1a?.Sindika.AspNet.App005.Services.GetWorkerConnectionInfoResponse\x12z\n\x0fSendSystemUsage\x12\x32.Sindika.AspNet.App005.Services.SystemUsageRequest\x1a\x33.Sindika.AspNet.App005.Services.SystemUsageResponse\x12\x85\x01\n\x0cUpdateStatus\x12\x39.Sindika.AspNet.App005.Services.UpdateWorkerStatusRequest\x1a:.Sindika.AspNet.App005.Services.UpdateWorkerStatusResponse2\x87\x02\n\x0cImageService\x12\x7f\n\x10GetLastImageDate\x12\x34.Sindika.AspNet.App005.Services.LastImageDateRequest\x1a\x35.Sindika.AspNet.App005.Services.LastImageDateResponse\x12v\n\x0bUploadImage\x12\x32.Sindika.AspNet.App005.Services.UploadImageRequest\x1a\x33.Sindika.AspNet.App005.Services.UploadImageResponse2\x8c\x01\n\x12HealthCheckService\x12v\n\x0bHealthCheck\x12\x32.Sindika.AspNet.App005.Services.HealthCheckRequest\x1a\x33.Sindika.AspNet.App005.Services.HealthCheckResponse2\x80\x01\n\x12VideoStreamService\x12j\n\x0bStreamVideo\x12*.Sindika.AspNet.App005.Services.VideoFrame\x1a-.Sindika.AspNet.App005.Services.VideoResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_worker.protos.VisionWorkerService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETWORKERCONNECTIONINFOREQUEST']._serialized_start=87
  _globals['_GETWORKERCONNECTIONINFOREQUEST']._serialized_end=134
  _globals['_GETWORKERCONNECTIONINFORESPONSE']._serialized_start=137
  _globals['_GETWORKERCONNECTIONINFORESPONSE']._serialized_end=328
  _globals['_SYSTEMUSAGEREQUEST']._serialized_start=331
  _globals['_SYSTEMUSAGEREQUEST']._serialized_end=586
  _globals['_GPUUSAGE']._serialized_start=589
  _globals['_GPUUSAGE']._serialized_end=768
  _globals['_SYSTEMUSAGERESPONSE']._serialized_start=770
  _globals['_SYSTEMUSAGERESPONSE']._serialized_end=825
  _globals['_LASTIMAGEDATEREQUEST']._serialized_start=827
  _globals['_LASTIMAGEDATEREQUEST']._serialized_end=883
  _globals['_LASTIMAGEDATERESPONSE']._serialized_start=885
  _globals['_LASTIMAGEDATERESPONSE']._serialized_end=970
  _globals['_UPLOADIMAGEREQUEST']._serialized_start=972
  _globals['_UPLOADIMAGEREQUEST']._serialized_end=1064
  _globals['_UPLOADIMAGERESPONSE']._serialized_start=1066
  _globals['_UPLOADIMAGERESPONSE']._serialized_end=1121
  _globals['_HEALTHCHECKREQUEST']._serialized_start=1123
  _globals['_HEALTHCHECKREQUEST']._serialized_end=1143
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=1145
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=1182
  _globals['_VIDEOFRAME']._serialized_start=1184
  _globals['_VIDEOFRAME']._serialized_end=1268
  _globals['_VIDEORESPONSE']._serialized_start=1270
  _globals['_VIDEORESPONSE']._serialized_end=1319
  _globals['_UPDATEWORKERSTATUSREQUEST']._serialized_start=1321
  _globals['_UPDATEWORKERSTATUSREQUEST']._serialized_end=1422
  _globals['_UPDATEWORKERSTATUSRESPONSE']._serialized_start=1424
  _globals['_UPDATEWORKERSTATUSRESPONSE']._serialized_end=1486
  _globals['_VISIONWORKERSERVICE']._serialized_start=1489
  _globals['_VISIONWORKERSERVICE']._serialized_end=1921
  _globals['_IMAGESERVICE']._serialized_start=1924
  _globals['_IMAGESERVICE']._serialized_end=2187
  _globals['_HEALTHCHECKSERVICE']._serialized_start=2190
  _globals['_HEALTHCHECKSERVICE']._serialized_end=2330
  _globals['_VIDEOSTREAMSERVICE']._serialized_start=2333
  _globals['_VIDEOSTREAMSERVICE']._serialized_end=2461
# @@protoc_insertion_point(module_scope)
