# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_worker/protos/HumanDetectionService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_worker/protos/HumanDetectionService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nedo_vision_worker/protos/HumanDetectionService.proto\x12\x1eSindika.AspNet.App005.Services\"@\n\x1cUpsertHumanDetectionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"E\n!UpsertHumanDetectionBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x8b\x02\n\x1bUpsertHumanDetectionRequest\x12\x11\n\tperson_id\x18\x01 \x01(\t\x12\x11\n\tworker_id\x18\x02 \x01(\t\x12\x18\n\x10worker_source_id\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\x0c\x12\x12\n\nimage_tile\x18\x05 \x01(\x0c\x12\x18\n\x10worker_timestamp\x18\x06 \x01(\t\x12\x18\n\x10\x63onfidence_score\x18\x07 \x01(\x01\x12\x10\n\x08\x62_box_x1\x18\x08 \x01(\x01\x12\x10\n\x08\x62_box_y1\x18\t \x01(\x01\x12\x10\n\x08\x62_box_x2\x18\n \x01(\x01\x12\x10\n\x08\x62_box_y2\x18\x0b \x01(\x01\x12\r\n\x05token\x18\x0c \x01(\t\"\x90\x01\n UpsertHumanDetectionBatchRequest\x12]\n\x18human_detection_requests\x18\x01 \x03(\x0b\x32;.Sindika.AspNet.App005.Services.UpsertHumanDetectionRequest\x12\r\n\x05token\x18\x02 \x01(\t2\xb6\x02\n\x19HumanDetectionGRPCService\x12\x83\x01\n\x06Upsert\x12;.Sindika.AspNet.App005.Services.UpsertHumanDetectionRequest\x1a<.Sindika.AspNet.App005.Services.UpsertHumanDetectionResponse\x12\x92\x01\n\x0bUpsertBatch\x12@.Sindika.AspNet.App005.Services.UpsertHumanDetectionBatchRequest\x1a\x41.Sindika.AspNet.App005.Services.UpsertHumanDetectionBatchResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_worker.protos.HumanDetectionService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UPSERTHUMANDETECTIONRESPONSE']._serialized_start=89
  _globals['_UPSERTHUMANDETECTIONRESPONSE']._serialized_end=153
  _globals['_UPSERTHUMANDETECTIONBATCHRESPONSE']._serialized_start=155
  _globals['_UPSERTHUMANDETECTIONBATCHRESPONSE']._serialized_end=224
  _globals['_UPSERTHUMANDETECTIONREQUEST']._serialized_start=227
  _globals['_UPSERTHUMANDETECTIONREQUEST']._serialized_end=494
  _globals['_UPSERTHUMANDETECTIONBATCHREQUEST']._serialized_start=497
  _globals['_UPSERTHUMANDETECTIONBATCHREQUEST']._serialized_end=641
  _globals['_HUMANDETECTIONGRPCSERVICE']._serialized_start=644
  _globals['_HUMANDETECTIONGRPCSERVICE']._serialized_end=954
# @@protoc_insertion_point(module_scope)
