# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nedo_vision_worker/protos/AIModelService.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nedo_vision_worker/protos/AIModelService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.nedo_vision_worker/protos/AIModelService.proto\x12\x1eSindika.AspNet.App005.Services\"9\n\x15GetAIModelListRequest\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"y\n\x16GetAIModelListResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12=\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32/.Sindika.AspNet.App005.Services.AIModelResponse\"\x93\x02\n\x0f\x41IModelResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16\x61i_model_category_code\x18\x03 \x01(\t\x12\x1a\n\x12\x61i_model_type_code\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x11\n\tfile_path\x18\x06 \x01(\t\x12\x11\n\tworker_id\x18\x07 \x01(\t\x12\x0f\n\x07\x63lasses\x18\x08 \x03(\t\x12N\n\x10ppe_class_groups\x18\t \x03(\x0b\x32\x34.Sindika.AspNet.App005.Services.AIModelPPEClassGroup\x12\x12\n\nmain_class\x18\n \x01(\t\"K\n\x14\x41IModelPPEClassGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncompliance\x18\x02 \x01(\t\x12\x11\n\tviolation\x18\x03 \x01(\t\"<\n\x16\x44ownloadAIModelRequest\x12\x13\n\x0b\x61i_model_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"-\n\x17\x44ownloadAIModelResponse\x12\x12\n\nfile_chunk\x18\x01 \x01(\x0c\x32\x9c\x02\n\x12\x41IModelGRPCService\x12\x7f\n\x0eGetAIModelList\x12\x35.Sindika.AspNet.App005.Services.GetAIModelListRequest\x1a\x36.Sindika.AspNet.App005.Services.GetAIModelListResponse\x12\x84\x01\n\x0f\x44ownloadAIModel\x12\x36.Sindika.AspNet.App005.Services.DownloadAIModelRequest\x1a\x37.Sindika.AspNet.App005.Services.DownloadAIModelResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nedo_vision_worker.protos.AIModelService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETAIMODELLISTREQUEST']._serialized_start=82
  _globals['_GETAIMODELLISTREQUEST']._serialized_end=139
  _globals['_GETAIMODELLISTRESPONSE']._serialized_start=141
  _globals['_GETAIMODELLISTRESPONSE']._serialized_end=262
  _globals['_AIMODELRESPONSE']._serialized_start=265
  _globals['_AIMODELRESPONSE']._serialized_end=540
  _globals['_AIMODELPPECLASSGROUP']._serialized_start=542
  _globals['_AIMODELPPECLASSGROUP']._serialized_end=617
  _globals['_DOWNLOADAIMODELREQUEST']._serialized_start=619
  _globals['_DOWNLOADAIMODELREQUEST']._serialized_end=679
  _globals['_DOWNLOADAIMODELRESPONSE']._serialized_start=681
  _globals['_DOWNLOADAIMODELRESPONSE']._serialized_end=726
  _globals['_AIMODELGRPCSERVICE']._serialized_start=729
  _globals['_AIMODELGRPCSERVICE']._serialized_end=1013
# @@protoc_insertion_point(module_scope)
