"""
Nedo Vision Worker Service Library

A library for running worker agents in the Nedo Vision platform.
"""

from .worker_service import WorkerService

__version__ = "1.2.3"
__all__ = ["WorkerService"] 